[GRASS-SVN] r41788 - in grass/branches/develbranch_6: lib/vector/neta vector vector/v.net.centrality

svn_grass at osgeo.org svn_grass at osgeo.org
Sat Apr 10 15:19:31 EDT 2010


Author: martinl
Date: 2010-04-10 15:19:28 -0400 (Sat, 10 Apr 2010)
New Revision: 41788

Modified:
   grass/branches/develbranch_6/lib/vector/neta/Makefile
   grass/branches/develbranch_6/vector/Makefile
   grass/branches/develbranch_6/vector/v.net.centrality/main.c
   grass/branches/develbranch_6/vector/vectorintro.html
Log:
neteler: activate new v.net.* modules; add to intro; typo fix
(merge r41784, r41785 from trunk)


Modified: grass/branches/develbranch_6/lib/vector/neta/Makefile
===================================================================
--- grass/branches/develbranch_6/lib/vector/neta/Makefile	2010-04-10 19:16:21 UTC (rev 41787)
+++ grass/branches/develbranch_6/lib/vector/neta/Makefile	2010-04-10 19:19:28 UTC (rev 41788)
@@ -12,4 +12,4 @@
 
 default: lib
 
-DOXNAME=neta
\ No newline at end of file
+DOXNAME=neta

Modified: grass/branches/develbranch_6/vector/Makefile
===================================================================
--- grass/branches/develbranch_6/vector/Makefile	2010-04-10 19:16:21 UTC (rev 41787)
+++ grass/branches/develbranch_6/vector/Makefile	2010-04-10 19:19:28 UTC (rev 41788)
@@ -34,10 +34,19 @@
 	v.neighbors \
 	v.net \
 	v.net.alloc \
+	v.net.allpairs \
+	v.net.bridge \
+	v.net.centrality \
+	v.net.components \
+	v.net.connectivity \
+	v.net.distance \
+	v.net.flow \
 	v.net.iso \
 	v.net.path \
 	v.net.salesman \
+	v.net.spanningtree \
 	v.net.steiner \
+	v.net.timetable \
 	v.net.visibility \
 	v.normal \
 	v.out.ascii \

Modified: grass/branches/develbranch_6/vector/v.net.centrality/main.c
===================================================================
--- grass/branches/develbranch_6/vector/vectorintro.html	2010-04-10 19:16:21 UTC (rev 41787)
+++ grass/branches/develbranch_6/vector/vectorintro.html	2010-04-10 19:19:28 UTC (rev 41788)
@@ -290,12 +290,21 @@
 <li> Vector maintenance: <a href="v.net.html">v.net</a></li>
 <li> Shortest path: <a href="d.path.html">d.path</a> and 
      <a href="v.net.path.html">v.net.path</a></li>
-<li> Traveling salesman (round trip): <a href="v.net.salesman.html">v.net.salesman</a></li>
+<li> Shortest path between all pairs of nodes <a href="v.net.allpairs.html">v.net.allpairs</a>
 <li> Allocation of sources (create subnetworks, e.g. police station zones):
      <a href="v.net.alloc.html">v.net.alloc</a></li>
-<li> Minimum Steiner trees (star-like connections, e.g. broadband cable 
+<li> Iso-distances (from centers): <a href="v.net.iso.html">v.net.iso</a></li>
+<li> Computes bridges and articulation points: <a href="v.net.bridge.html">v.net.bridge</a></li>
+<li> Computes degree, centrality, betweeness, closeness and eigenvector centrality measures: <a href="v.net.centrality.html">v.net.centrality</a></li>
+<li> Computes strongly and weakly connected components: <a href="v.net.components.html">v.net.components</a></li>
+<li> Computes vertex connectivity between two sets of nodes: <a href="v.net.connectivity.html">v.net.connectivity</a></li>
+<li> Computes shortest distance via the network between the given sets of features: <a href="v.net.distance.html">v.net.distance</a></li>
+<li> Computes the maximum flow between two sets of nodes: <a href="v.net.flow.html">v.net.flow</a></li>
+<li> Computes minimum spanning tree:<a href="v.net.spanningtree.html">v.net.spanningtree</a></li>
+<li> Minimum Steiner trees (star-like connections, e.g. broadband cable
      connections): <a href="v.net.steiner.html">v.net.steiner</a></li>
-<li> Iso-distances (from centers): <a href="v.net.iso.html">v.net.iso</a></li>
+<li> Finds shortest path using timetables: <a href="v.net.timetable.html">v.net.timetable</a></li>
+<li> Traveling salesman (round trip): <a href="v.net.salesman.html">v.net.salesman</a></li>
 </ul>
 
 Vector directions are defined by the digitizing direction (a--&gt;--b).



More information about the grass-commit mailing list
--- grass/branches/develbranch_6/vector/v.net.centrality/main.c	2010-04-10 19:16:21 UTC (rev 41787)
+++ grass/branches/develbranch_6/vector/v.net.centrality/main.c	2010-04-10 19:19:28 UTC (rev 41788)
@@ -5,7 +5,7 @@
  *
  * AUTHOR(S):  Daniel Bundala
  *
  * PURPOSE:    This module computes various cetrality measures
  *
  * COPYRIGHT:  (C) 2002-2005 by the GRASS Development Team
  *
@@ -97,7 +97,7 @@
     G_add_keyword(_("centrality measures"));
     module->description =
 	_("Computes degree, centrality, betweeness, closeness and eigenvector "
-	 "cetrality measures in the network.");
+	 "centrality measures in the network.");
 
     /* Define the different options as defined in gis.h */
     map_in = G_define_standard_option(G_OPT_V_INPUT);
@@ -5,7 +5,7 @@
  * AUTHOR(S):  Daniel Bundala
  *
- * PURPOSE:    This module computes various cetrality measures
+ * PURPOSE:    This module computes various centrality measures
  *
  * COPYRIGHT:  (C) 2002-2005 by the GRASS Development Team

Modified: grass/branches/develbranch_6/vector/vectorintro.html
===================================================================